@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+from functools import cached_property
 from typing import Literal
 
 import numpy as np
@@ -37,7 +38,11 @@ class Cest15NCwSettings(CestSettings):
     b1_inh_scale: float = 0.1
     b1_inh_res: int = 11
 
-    @property
+    @cached_property
+    def start_terms(self) -> list[str]:
+        return [f"iz{self.suffix}"]
+
+    @cached_property
     def detection(self) -> str:
         return f"[iz_{self.observed_state}]"
 
@@ -101,7 +106,9 @@ class Cest15NCwSequence:
     def calculate(self, spectrometer: Spectrometer, data: Data) -> ArrayFloat:
         offsets = data.metadata
 
-        start = spectrometer.get_start_magnetization(terms=["iz"], atom="n")
+        start = spectrometer.get_start_magnetization(
+            terms=self.settings.start_terms, atom="n"
+        )
 
         intensities: dict[float, ArrayFloat] = {}
 
