@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+from functools import cached_property
 from typing import Literal
 
 import numpy as np
@@ -32,16 +33,17 @@ class Cpmg1HnApSettings(CpmgSettings):
     pw90: float
     time_equil_1: float = 0.0
     time_equil_2: float = 0.0
+    cs_evolution_prior: bool = True
 
-    @property
+    @cached_property
     def t_neg(self) -> float:
         return -2.0 * self.pw90 / np.pi
 
-    @property
-    def start(self) -> list[str]:
-        return [f"2izsz_{self.observed_state}"]
+    @cached_property
+    def start_terms(self) -> list[str]:
+        return [f"2izsz{self.suffix}"]
 
-    @property
+    @cached_property
     def detection(self) -> str:
         return f"[2izsz_{self.observed_state}]"
 
@@ -115,7 +117,7 @@ class Cpmg1HnApSequence:
         p180pmx = 0.5 * (p180[0] + p180[2])  # +/- phase cycling
 
         # Getting the starting magnetization
-        start = spectrometer.get_start_magnetization(terms=self.settings.start)
+        start = spectrometer.get_start_magnetization(terms=self.settings.start_terms)
 
         # Calculating the instensities as a function of ncyc
         part1 = d_neg @ p90[0] @ d_eq_1 @ start
