@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+from functools import cached_property
 from typing import Literal
 
 import numpy as np
@@ -32,21 +33,23 @@ class CpmgChd21HApSettings(CpmgSettings):
     pw90: float
     time_equil: float = 0.0
 
-    @property
+    @cached_property
     def t_neg(self) -> float:
         return -2.0 * self.pw90 / np.pi
 
-    @property
+    @cached_property
+    def start_terms(self) -> list[str]:
+        return [f"2izsz{self.suffix}"]
+
+    @cached_property
     def detection(self) -> str:
         return f"[2izsz_{self.observed_state}]"
 
 
 class CpmgChd21HApConfig(
     ExperimentConfiguration[
-        CpmgChd21HApSettings,
-        ConditionsWithValidations,
-        RelaxationDataSettings,
-    ],
+        CpmgChd21HApSettings, ConditionsWithValidations, RelaxationDataSettings
+    ]
 ):
     @property
     def to_be_fitted(self) -> ToBeFitted:
@@ -104,7 +107,7 @@ class CpmgChd21HApSequence:
         p180pmx = 0.5 * (p180[0] + p180[2])  # +/- phase cycling
 
         # Getting the starting magnetization
-        start = spectrometer.get_start_magnetization(terms=["2izsz"])
+        start = spectrometer.get_start_magnetization(self.settings.start_terms)
 
         # Calculating the instensities as a function of ncyc
         part1 = d_neg @ p90[0] @ start
