@@ -1,20 +1,16 @@
 from __future__ import annotations
 
 from functools import lru_cache
-from typing import TYPE_CHECKING
 
 import numpy as np
 from scipy.constants import constants
 
+from chemex.configuration.conditions import Conditions
 from chemex.models.constraints import pop_2st
 from chemex.models.factory import model_factory
-from chemex.parameters.setting import NameSetting
-from chemex.parameters.setting import ParamLocalSetting
+from chemex.parameters.setting import NameSetting, ParamLocalSetting
 from chemex.parameters.userfunctions import user_function_registry
 
-if TYPE_CHECKING:
-    from chemex.configuration.conditions import Conditions
-
 NAME = "2st_eyring"
 
 PL = ("p_total", "l_total")
@@ -23,7 +19,11 @@ TPL = ("temperature", "p_total", "l_total")
 
 @lru_cache(maxsize=100)
 def calculate_kij_2st_eyring(
-    dh_b: float, ds_b: float, dh_ab: float, ds_ab: float, temperature: float
+    dh_b: float,
+    ds_b: float,
+    dh_ab: float,
+    ds_ab: float,
+    temperature: float,
 ) -> dict[str, float]:
     kelvin = temperature + 273.15
     kbt_h = constants.k * kelvin / constants.h
@@ -60,24 +60,24 @@ def make_settings_2st_eyring(conditions: Conditions) -> dict[str, ParamLocalSett
         "kab": ParamLocalSetting(
             name_setting=NameSetting("kab", "", TPL),
             min=0.0,
-            expr=f"kij_2st_eyring({{dh_b}}, {{ds_b}}, {{dh_ab}}, {{ds_ab}}, {celsius})['kab']",
+            expr=f"kij_2st_eyring({{dh_b}},{{ds_b}},{{dh_ab}},{{ds_ab}},{celsius})['kab']",
         ),
         "kba": ParamLocalSetting(
             name_setting=NameSetting("kba", "", TPL),
             min=0.0,
-            expr=f"kij_2st_eyring({{dh_b}}, {{ds_b}}, {{dh_ab}}, {{ds_ab}}, {celsius})['kba']",
+            expr=f"kij_2st_eyring({{dh_b}},{{ds_b}},{{dh_ab}},{{ds_ab}},{celsius})['kba']",
         ),
         "pa": ParamLocalSetting(
             name_setting=NameSetting("pa", "", TPL),
             min=0.0,
             max=1.0,
-            expr="pop_2st({kab}, {kba})['pa']",
+            expr="pop_2st({kab},{kba})['pa']",
         ),
         "pb": ParamLocalSetting(
             name_setting=NameSetting("pb", "", TPL),
             min=0.0,
             max=1.0,
-            expr="pop_2st({kab}, {kba})['pb']",
+            expr="pop_2st({kab},{kba})['pb']",
         ),
     }
 
