@@ -2,18 +2,21 @@ from __future__ import annotations
 
 from collections import defaultdict
 from dataclasses import dataclass
-from functools import cache
+from functools import cache, cached_property, partial
 from itertools import permutations, product
 from typing import Literal
 
 import numpy as np
+from numpy.typing import NDArray
 
 from chemex.models.model import model
+from chemex.parameters.spin_system.nucleus import Nucleus, str2nucleus
 from chemex.typing import ArrayFloat
 
-DictArrayFloat = dict[str, ArrayFloat]
+DictArray = dict[str, NDArray[np.number]]
 
 _BASES = {
+    "i-": ["i-"],
     "ixy": ["ix", "iy"],
     "iz": ["iz"],
     "izsz": ["iz", "2izsz"],
@@ -63,7 +66,7 @@ _BASES = {
     ],
 }
 _TRANSITIONS = {
-    "r2_i_{state}": (("ix", "ix", -1.0), ("iy", "iy", -1.0)),
+    "r2_i_{state}": (("ix", "ix", -1.0), ("iy", "iy", -1.0), ("i-", "i-", -1.0)),
     "r2_s_{state}": (("sx", "sx", -1.0), ("sy", "sy", -1.0)),
     "r1_i_{state}": (("iz", "iz", -1.0), ("iz", "ie", +1.0)),
     "r1_s_{state}": (("sz", "sz", -1.0), ("sz", "se", +1.0)),
@@ -133,6 +136,7 @@ _TRANSITIONS = {
     "cs_i_{state}": (
         ("ix", "iy", -1.0),
         ("iy", "ix", +1.0),
+        ("i-", "i-", +1.0j),
         ("2ixsx", "2iysx", -1.0),
         ("2iysx", "2ixsx", +1.0),
         ("2ixsy", "2iysy", -1.0),
@@ -153,6 +157,7 @@ _TRANSITIONS = {
     "carrier_i": (
         ("ix", "iy", +1.0),
         ("iy", "ix", -1.0),
+        ("i-", "i-", -1.0j),
         ("2ixsx", "2iysx", +1.0),
         ("2iysx", "2ixsx", -1.0),
         ("2ixsy", "2iysy", +1.0),
@@ -173,6 +178,7 @@ _TRANSITIONS = {
     "offset_i": (
         ("ix", "iy", +2.0 * np.pi),
         ("iy", "ix", -2.0 * np.pi),
+        ("i-", "i-", -2.0j * np.pi),
         ("2ixsx", "2iysx", +2.0 * np.pi),
         ("2iysx", "2ixsx", -2.0 * np.pi),
         ("2ixsy", "2iysy", +2.0 * np.pi),
@@ -268,18 +274,28 @@ _TRANSITIONS = {
         ("2izsx", "2izsz", +2.0 * np.pi),
     ),
 }
-_ATOMS = {
-    atoms: {"i": atoms[0], "s": atoms[1]} for atoms in ("hn", "hc", "nh", "ch", "cn")
+
+_NUCLEI = {
+    pair: {"i": str2nucleus(pair[0]), "s": str2nucleus(pair[1])}
+    for pair in ("hn", "hc", "nh", "ch", "cn")
 }
 
-
 @cache
-def _build_vectors(basis: Basis) -> DictArrayFloat:
+def _build_vectors(basis: Basis) -> DictArray:
+    """Build vector representations for basis components."""
     size = len(basis) * len(model.states)
-    vectors: defaultdict[str, ArrayFloat] = defaultdict(lambda: np.zeros((size, 1)))
-    for index, (state, name) in enumerate(product(model.states, basis.components)):
-        vectors[f"{name}_{state}"][index] = 1.0
-        vectors[name][index] = 1.0
+
+    # Initialize empty vectors dictionary with zero arrays
+    vectors: defaultdict[str, ArrayFloat] = defaultdict(
+        lambda: np.zeros((size, 1))
+    )
+
+    # Populate vectors for each state/component combination
+    for idx, (state, component) in enumerate(product(model.states, basis.components)):
+        state_component = f"{component}_{state}"
+        vectors[state_component][idx] = 1.0
+        vectors[component][idx] = 1.0
+
     return dict(vectors)
 
 
@@ -287,10 +303,10 @@ def _get_indices(
     basis: Basis,
     transition_name: str,
     state: str,
-) -> tuple[tuple[list[int], list[int]], list[float]]:
+) -> tuple[tuple[list[int], list[int]], list[float | complex]]:
     rows: list[int] = []
     cols: list[int] = []
-    vals: list[float] = []
+    vals: list[float | complex] = []
     offset = model.states.index(state) * len(basis)
     for start, end, value in _TRANSITIONS[transition_name]:
         if {start, end}.issubset(basis.components):
@@ -300,9 +316,12 @@ def _get_indices(
     return (rows, cols), vals
 
 
-def _build_spin_matrices(basis: Basis) -> DictArrayFloat:
+def _build_spin_matrices(basis: Basis) -> DictArray:
     size = len(basis) * len(model.states)
-    matrices: DictArrayFloat = defaultdict(lambda: np.zeros((size, size)))
+
+    matrices: DictArray = defaultdict(partial(np.zeros, (size, size), dtype=complex))
+
+    # Build matrices for each transition
     for transition_name, state in product(_TRANSITIONS, model.states):
         if not basis.type.endswith("_diff") and transition_name.startswith("d_"):
             continue
@@ -310,11 +329,17 @@ def _build_spin_matrices(basis: Basis) -> DictArrayFloat:
         indices, values = _get_indices(basis, transition_name, state)
         if values:
             matrices[name][indices] = values
+
+    # Remove imaginary parts from real matrices
+    for key, matrix in matrices.items():
+        if not np.iscomplex(matrix).any():
+            matrices[key] = matrix.real
+
     return matrices
 
 
-def _build_exchange_matrices(basis: Basis) -> DictArrayFloat:
-    matrices: DictArrayFloat = {}
+def _build_exchange_matrices(basis: Basis) -> DictArray:
+    matrices: DictArray = {}
     for (i1, s1), (i2, s2) in permutations(enumerate(model.states), r=2):
         name = f"k{s1}{s2}"
         matrix = np.zeros((len(model.states), len(model.states)))
@@ -323,11 +348,6 @@ def _build_exchange_matrices(basis: Basis) -> DictArrayFloat:
     return matrices
 
 
-@cache
-def _build_matrices(basis: Basis) -> DictArrayFloat:
-    return _build_exchange_matrices(basis) | _build_spin_matrices(basis)
-
-
 @dataclass(frozen=True)
 class Basis:
     type: str
@@ -343,20 +363,30 @@ class Basis:
         return _BASES[self.type]
 
     @property
-    def atoms(self) -> dict[str, str]:
+    def components_states(self) -> list[str]:
+        return [
+            f"{comp}_{state}" for state, comp in product(model.states, self.components)
+        ]
+
+    @property
+    def nuclei(self) -> dict[str, Nucleus]:
         return {
-            letter: atom
-            for letter, atom in _ATOMS.get(self.spin_system, {}).items()
+            letter: nucleus
+            for letter, nucleus in _NUCLEI.get(self.spin_system, {}).items()
             if letter in self.type
         }
 
     @property
-    def vectors(self) -> DictArrayFloat:
+    def vectors(self) -> DictArray:
         return dict(_build_vectors(self))
 
+    @cached_property
+    def matrices(self) -> DictArray:
+        return _build_exchange_matrices(self) | _build_spin_matrices(self)
+
     @property
-    def matrices(self) -> DictArrayFloat:
-        return _build_matrices(self)
+    def matrices_ref(self) -> DictArray:
+        return _build_exchange_matrices(self) | _build_spin_matrices(self)
 
     @property
     def required_names(self) -> set[str]:
@@ -364,5 +394,15 @@ class Basis:
         required_names |= {f"p{state}" for state in model.states}
         return required_names
 
+    def scale_matrices(self, names: list[str] | str, value: float) -> None:
+        if isinstance(names, str):
+            names = [names]
+        for name in names:
+            state_names = {name.format(state=state) for state in model.states}
+            for state_name in state_names & self.matrices.keys():
+                self.matrices[state_name] = (
+                    np.sign(self.matrices_ref[state_name]) * value
+                )
+
     def __len__(self) -> int:
         return len(self.components)
